@@ -2,7 +2,10 @@ from unittest.mock import Mock
 
 import pytest
 
-from federation.entities.diaspora.entities import DiasporaPost
+# noinspection PyUnresolvedReferences
+from federation.tests.fixtures.entities import *
+from federation.tests.fixtures.types import *
+from federation.tests.fixtures.keys import get_dummy_private_key
 
 
 @pytest.fixture(autouse=True)
@@ -22,5 +25,10 @@ def disable_network_calls(monkeypatch):
 
 
 @pytest.fixture
-def diasporapost():
-    return DiasporaPost()
+def private_key():
+    return get_dummy_private_key()
+
+
+@pytest.fixture
+def public_key(private_key):
+    return private_key.publickey().exportKey()
